@@ -42,4 +42,11 @@ void                   phosh_notify_manager_close_all_notifications  (PhoshNotif
                                                                       PhoshNotificationReason  reaseon);
 gboolean               phosh_notify_manager_get_show_notification_banner (PhoshNotifyManager *self,
                          PhoshNotification  *notification);
+
+guint                  phosh_notify_manager_add_shell_notification (PhoshNotifyManager *self,
+                                                                    const char         *summary,
+                                                                    const char         *body,
+                                                                    const char         *icon,
+                                                                    int                 expire_timeout);
+
 G_END_DECLS
