@@ -15,8 +15,8 @@
 #include "shell.h"
 #include "settings.h"
 #include "quick-setting.h"
+#include "settings/audio-settings.h"
 #include "settings/brightness.h"
-#include "settings/gvc-channel-bar.h"
 #include "torch-info.h"
 #include "torch-manager.h"
 #include "vpn-manager.h"
@@ -24,10 +24,8 @@
 #include "notifications/notify-manager.h"
 #include "notifications/notification-frame.h"
 #include "rotateinfo.h"
+#include "util.h"
 
-#include <pulse/pulseaudio.h>
-#include "gvc-mixer-control.h"
-#include "gvc-mixer-stream.h"
 #include <gio/gdesktopappinfo.h>
 #include <xkbcommon/xkbcommon.h>
 
@@ -68,15 +66,8 @@ typedef struct _PhoshSettings
   GtkWidget *box_settings;
   GtkWidget *quick_settings;
   GtkWidget *scale_brightness;
-  GtkWidget *output_vol_bar;
   GtkWidget *media_player;
-
-  /* Output volume control */
-  GvcMixerControl *mixer_control;
-  GvcMixerStream *output_stream;
-  gboolean allow_volume_above_100_percent;
-  gboolean setting_volume;
-  gboolean is_headphone;
+  PhoshAudioSettings *audio_settings;
 
   /* The area with media widget, notifications */
   GtkWidget *box_bottom_half;
@@ -248,11 +239,24 @@ open_settings_panel (PhoshSettings *self, const char *panel)
 }
 
 
+static void
+on_launch_panel_activated (GSimpleAction *action, GVariant *param, gpointer data)
+{
+  PhoshSettings *self = PHOSH_SETTINGS (data);
+  const char *panel;
+
+  panel = g_variant_get_string (param, NULL);
+
+  open_settings_panel (self, panel);
+  phosh_audio_settings_hide_details (self->audio_settings);
+}
+
+
 static void
 rotation_setting_long_pressed_cb (PhoshSettings *self)
 {
   PhoshShell *shell = phosh_shell_get_default ();
-  PhoshRotateInfoMode mode;
+  PhoshRotationManagerMode mode;
   PhoshRotationManager *rotation_manager;
 
   rotation_manager = phosh_shell_get_rotation_manager (shell);
@@ -405,24 +409,6 @@ docked_setting_long_pressed_cb (PhoshSettings *self)
 }
 
 
-static void
-update_output_vol_bar (PhoshSettings *self)
-{
-  GtkAdjustment *adj;
-
-  self->setting_volume = TRUE;
-  gvc_channel_bar_set_base_volume (GVC_CHANNEL_BAR (self->output_vol_bar),
-                                   gvc_mixer_stream_get_base_volume (self->output_stream));
-  gvc_channel_bar_set_is_amplified (GVC_CHANNEL_BAR (self->output_vol_bar),
-                                    self->allow_volume_above_100_percent &&
-                                    gvc_mixer_stream_get_can_decibel (self->output_stream));
-  adj = GTK_ADJUSTMENT (gvc_channel_bar_get_adjustment (GVC_CHANNEL_BAR (self->output_vol_bar)));
-  g_debug ("Adjusting volume to %d", gvc_mixer_stream_get_volume (self->output_stream));
-  gtk_adjustment_set_value (adj, gvc_mixer_stream_get_volume (self->output_stream));
-  self->setting_volume = FALSE;
-}
-
-
 static void
 on_vpn_setting_clicked (PhoshSettings *self)
 {
@@ -447,127 +433,23 @@ on_vpn_setting_long_pressed (PhoshSettings *self)
 
 
 static void
-output_stream_notify_is_muted_cb (GvcMixerStream *stream, GParamSpec *pspec, gpointer data)
+on_is_headphone_changed (PhoshSettings      *self,
+                         GParamSpec         *pspec,
+                         PhoshAudioSettings *audio_settings)
 {
-  PhoshSettings *self = PHOSH_SETTINGS (data);
-  gboolean muted;
-
-  muted = gvc_mixer_stream_get_is_muted (stream);
-  if (!self->setting_volume) {
-    gvc_channel_bar_set_is_muted (GVC_CHANNEL_BAR (self->output_vol_bar), muted);
-    if (!muted)
-      update_output_vol_bar (self);
-  };
-
-}
-
-
-static void
-output_stream_notify_volume_cb (GvcMixerStream *stream, GParamSpec *pspec, gpointer data)
-{
-  PhoshSettings *self = PHOSH_SETTINGS (data);
-
-  if (!self->setting_volume)
-    update_output_vol_bar (self);
-}
-
-
-static void
-on_output_stream_port_changed (GvcMixerStream *stream, GParamSpec *pspec, gpointer data)
-{
-  PhoshSettings *self = PHOSH_SETTINGS (data);
-  const char *form_factor;
-  gboolean is_headphone = FALSE;
-  const char *icon = "audio-speakers-symbolic";
-  const GvcMixerStreamPort *port;
-  PhoshMediaPlayer *media_player = PHOSH_MEDIA_PLAYER (self->media_player);
-
-  port = gvc_mixer_stream_get_port (stream);
-  g_return_if_fail (port);
-  g_debug ("Port changed: %s (%s)", port->human_port ?: port->port, port->port);
-
-  form_factor = gvc_mixer_stream_get_form_factor (stream);
-  if (g_strcmp0 (form_factor, "headset") == 0 ||
-      g_strcmp0 (form_factor, "headphone") == 0) {
-    is_headphone = TRUE;
-  }
-
-  if (g_strcmp0 (port->port, "[Out] Headphones") == 0 ||
-      g_strcmp0 (port->port, "analog-output-headphones") == 0) {
-    is_headphone = TRUE;
-  }
-
-  if (is_headphone == self->is_headphone)
-    return;
-
-  self->is_headphone = is_headphone;
-  if (is_headphone)
-    icon = "audio-headphones-symbolic";
-  else if (phosh_media_player_get_is_playable (media_player) &&
-           phosh_media_player_get_status (media_player) == PHOSH_MEDIA_PLAYER_STATUS_PLAYING) {
-    phosh_media_player_toggle_play_pause (media_player);
-  }
-
-  gvc_channel_bar_set_icon_name (GVC_CHANNEL_BAR (self->output_vol_bar), icon);
-}
-
-
-static void
-mixer_control_output_update_cb (GvcMixerControl *mixer, guint id, gpointer data)
-{
-  PhoshSettings *self = PHOSH_SETTINGS (data);
-
-  g_debug ("Audio output updated: %d", id);
+  PhoshMediaPlayer *media_player;
 
   g_return_if_fail (PHOSH_IS_SETTINGS (self));
+  g_return_if_fail (PHOSH_IS_AUDIO_SETTINGS (audio_settings));
+  media_player = PHOSH_MEDIA_PLAYER (self->media_player);
 
-  if (self->output_stream)
-    g_signal_handlers_disconnect_by_data (self->output_stream, self);
+  if (phosh_audio_settings_get_output_is_headphone (self->audio_settings) ||
+      !phosh_media_player_get_is_playable (media_player) ||
+      phosh_media_player_get_status (media_player) != PHOSH_MEDIA_PLAYER_STATUS_PLAYING) {
+    return;
+  }
 
-  g_set_object (&self->output_stream,
-                gvc_mixer_control_get_default_sink (self->mixer_control));
-  g_return_if_fail (self->output_stream);
-
-  g_signal_connect_object (self->output_stream,
-                           "notify::volume",
-                           G_CALLBACK (output_stream_notify_volume_cb),
-                           self, 0);
-
-  g_signal_connect_object (self->output_stream,
-                           "notify::is-muted",
-                           G_CALLBACK (output_stream_notify_is_muted_cb),
-                           self, 0);
-
-  g_signal_connect_object (self->output_stream,
-                           "notify::port",
-                           G_CALLBACK (on_output_stream_port_changed),
-                           self, 0);
-  on_output_stream_port_changed (self->output_stream, NULL, self);
-
-  update_output_vol_bar (self);
-}
-
-
-static void
-vol_bar_value_changed_cb (GvcChannelBar *bar, PhoshSettings *self)
-{
-  double volume, rounded;
-  g_autofree char *name = NULL;
-
-  if (!self->output_stream)
-    self->output_stream = g_object_ref (gvc_mixer_control_get_default_sink (self->mixer_control));
-
-  volume = gvc_channel_bar_get_volume (bar);
-  rounded = round (volume);
-
-  g_object_get (self->output_vol_bar, "name", &name, NULL);
-  g_debug ("Setting stream volume %lf (rounded: %lf) for bar '%s'", volume, rounded, name);
-
-  g_return_if_fail (self->output_stream);
-  if (gvc_mixer_stream_set_volume (self->output_stream, (pa_volume_t) rounded) != FALSE)
-    gvc_mixer_stream_push_volume (self->output_stream);
-
-  gvc_mixer_stream_change_is_muted (self->output_stream, (int) rounded == 0);
+  phosh_media_player_toggle_play_pause (media_player);
 }
 
 
@@ -660,11 +542,11 @@ on_torch_brightness_changed (PhoshSettings *self, GParamSpec *pspec, PhoshTorchM
 
 
 static void
-on_notifcation_frames_items_changed (PhoshSettings *self,
-                                     guint          position,
-                                     guint          removed,
-                                     guint          added,
-                                     GListModel    *list)
+on_notification_frames_items_changed (PhoshSettings *self,
+                                      guint          position,
+                                      guint          removed,
+                                      guint          added,
+                                      GListModel    *list)
 {
   gboolean is_empty;
   const char *child_name;
@@ -713,39 +595,15 @@ setup_torch (PhoshSettings *self)
 }
 
 
-static void
-setup_volume_bar (PhoshSettings *self)
-{
-  self->output_vol_bar = gvc_channel_bar_new ();
-  gtk_widget_set_sensitive (self->output_vol_bar, TRUE);
-  gtk_widget_show (self->output_vol_bar);
-
-  gtk_box_pack_start (GTK_BOX (self->box_sliders), self->output_vol_bar, FALSE, FALSE, 0);
-  gtk_box_reorder_child (GTK_BOX (self->box_sliders), self->output_vol_bar, 2);
-
-  self->mixer_control = gvc_mixer_control_new ("Phone Shell Volume Control");
-  g_return_if_fail (self->mixer_control);
-
-  gvc_mixer_control_open (self->mixer_control);
-  g_signal_connect (self->mixer_control,
-                    "active-output-update",
-                    G_CALLBACK (mixer_control_output_update_cb),
-                    self);
-  g_signal_connect (self->output_vol_bar,
-                    "value-changed",
-                    G_CALLBACK (vol_bar_value_changed_cb),
-                    self);
-}
-
-
 static void
 phosh_settings_constructed (GObject *object)
 {
   PhoshSettings *self = PHOSH_SETTINGS (object);
   PhoshNotifyManager *manager;
 
+  G_OBJECT_CLASS (phosh_settings_parent_class)->constructed (object);
+
   setup_brightness_range (self);
-  setup_volume_bar (self);
   setup_torch (self);
 
   g_signal_connect (self->quick_settings,
@@ -761,19 +619,17 @@ phosh_settings_constructed (GObject *object)
                            NULL);
   g_signal_connect_object (phosh_notify_manager_get_list (manager),
                            "items-changed",
-                           G_CALLBACK (on_notifcation_frames_items_changed),
+                           G_CALLBACK (on_notification_frames_items_changed),
                            self,
                            G_CONNECT_SWAPPED);
-  on_notifcation_frames_items_changed (self, -1, -1, -1,
-                                       G_LIST_MODEL (phosh_notify_manager_get_list (manager)));
+  on_notification_frames_items_changed (self, -1, -1, -1,
+                                        G_LIST_MODEL (phosh_notify_manager_get_list (manager)));
 
   g_object_bind_property (phosh_shell_get_default (),
                           "locked",
                           self,
                           "on-lockscreen",
                           G_BINDING_SYNC_CREATE);
-
-  G_OBJECT_CLASS (phosh_settings_parent_class)->constructed (object);
 }
 
 
@@ -784,8 +640,6 @@ phosh_settings_dispose (GObject *object)
 
   brightness_dispose ();
 
-  g_clear_object (&self->output_stream);
-
   g_clear_object (&self->torch_manager);
 
   G_OBJECT_CLASS (phosh_settings_parent_class)->dispose (object);
@@ -797,14 +651,12 @@ phosh_settings_finalize (GObject *object)
 {
   PhoshSettings *self = PHOSH_SETTINGS (object);
 
-  g_clear_object (&self->mixer_control);
   g_clear_handle_id (&self->debounce_handle, g_source_remove);
 
   G_OBJECT_CLASS (phosh_settings_parent_class)->finalize (object);
 }
 
 
-
 static void
 phosh_settings_class_init (PhoshSettingsClass *klass)
 {
@@ -850,6 +702,9 @@ phosh_settings_class_init (PhoshSettingsClass *klass)
       G_TYPE_FROM_CLASS (klass), G_SIGNAL_RUN_LAST, 0, NULL, NULL,
       NULL, G_TYPE_NONE, 0);
 
+  g_type_ensure (PHOSH_TYPE_AUDIO_SETTINGS);
+
+  gtk_widget_class_bind_template_child (widget_class, PhoshSettings, audio_settings);
   gtk_widget_class_bind_template_child (widget_class, PhoshSettings, box_bottom_half);
   gtk_widget_class_bind_template_child (widget_class, PhoshSettings, box_sliders);
   gtk_widget_class_bind_template_child (widget_class, PhoshSettings, box_settings);
@@ -876,20 +731,42 @@ phosh_settings_class_init (PhoshSettingsClass *klass)
   gtk_widget_class_bind_template_callback (widget_class, wifi_setting_long_pressed_cb);
   gtk_widget_class_bind_template_callback (widget_class, wwan_setting_clicked_cb);
   gtk_widget_class_bind_template_callback (widget_class, wwan_setting_long_pressed_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_is_headphone_changed);
   gtk_widget_class_bind_template_callback (widget_class, on_notifications_clear_all_clicked);
   gtk_widget_class_bind_template_callback (widget_class, on_torch_scale_value_changed);
   gtk_widget_class_bind_template_callback (widget_class, on_vpn_setting_long_pressed);
   gtk_widget_class_bind_template_callback (widget_class, on_vpn_setting_clicked);
-
   gtk_widget_class_bind_template_callback (widget_class, update_drag_handle_offset);
 }
 
 
+static const GActionEntry entries[] = {
+  { .name = "launch-panel", .activate = on_launch_panel_activated, .parameter_type = "s" },
+};
+
+
 static void
 phosh_settings_init (PhoshSettings *self)
 {
+  g_autoptr (GActionMap) map = NULL;
+  GAction *action;
+
   gtk_widget_init_template (GTK_WIDGET (self));
 
+  map = G_ACTION_MAP (g_simple_action_group_new ());
+  g_action_map_add_action_entries (map,
+                                   entries,
+                                   G_N_ELEMENTS (entries),
+                                   self);
+  gtk_widget_insert_action_group (GTK_WIDGET (self),
+                                  "settings",
+                                  G_ACTION_GROUP (map));
+
+  action = g_action_map_lookup_action (map, "launch-panel");
+  g_object_bind_property (self, "on-lockscreen",
+                          action, "enabled",
+                          G_BINDING_SYNC_CREATE | G_BINDING_INVERT_BOOLEAN);
+
   g_signal_connect (self, "size-allocate", G_CALLBACK (on_size_allocate), NULL);
 }
 
